<?php
/**
 * The featured layouts
 *
 * @package Blocks
 */

defined( 'WPINC' ) || exit;

/**
 * Class for featured layouts.
 */
class Blocks_Featured_Layouts extends Blocks_Base {

	/**
	 * Current layout.
	 *
	 * @var string
	 */
	public $current = null;

	/**
	 * Hold sections.
	 *
	 * @var array
	 */
	private $sections = null;

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->sections = blocks_get_settings( 'mts_featured_categories' );
	}

	/**
	 * Render layout
	 */
	public function render() {

		if ( empty( $this->sections ) ) {
			$this->current = array(
				'layout'         => 'default',
				'posts_layout'   => 'layout-default',
				'excerpt_length' => 20,
				'unique_id'      => 'nothing',
				'is_latest'      => true,
			);

			get_template_part( 'template-parts/posts', 'default' );
			return;
		}

		foreach ( $this->sections as $section ) :
			$posts_layout = $section['mts_thumb_layout'];
			$layout       = $posts_layout;
			if ( 'layout-default' === $posts_layout ) {
				$layout = 'default';
			}

			if ( is_paged() ) {
				$this->current = array(
					'layout'         => $layout,
					'excerpt_length' => 20,
					'unique_id'      => $section['unique_id'],
				);
				get_template_part( 'template-parts/posts', $layout );
				return;
			}

			$section = wp_parse_args(
				array_filter( $section ),
				array(
					'mts_thumb_layout'                 => '',
					'mts_featured_category_postsnum'   => 4,
					'mts_featured_category_excerpt'    => 25,
					'mts_featured_category_background' => '',
					'mts_featured_category_margin'     => '',
					'mts_featured_category_padding'    => '',
					'unique_id'                        => '',
				)
			);

			$category     = $section['mts_featured_category'];
			$posts_layout = $section['mts_thumb_layout'];

			if ( 'latest' !== $category ) {
				$this->category_posts( $category, $section['mts_featured_category_postsnum'] );
			}

			$this->current = array(
				'layout'           => $layout,
				'category'         => $category,
				'unique_id'        => $section['unique_id'],
				'is_latest'        => 'latest' !== $category,
				'posts_layout'     => $posts_layout,
				'posts_count'      => $section['mts_featured_category_postsnum'],
				'excerpt_length'   => $section['mts_featured_category_excerpt'],
				'posts_background' => $section['mts_featured_category_background'],
				'posts_margin'     => $section['mts_featured_category_margin'],
				'posts_padding'    => $section['mts_featured_category_padding'],
			);

			if ( have_posts() ) {
				get_template_part( 'template-parts/posts', $layout );
			}

		endforeach;
	}

	/**
	 * Genrate post_container classes
	 */
	public function get_post_container_class() {
		$classes   = array();
		$classes[] = 'layout-' . $this->current['unique_id'];
		$classes[] = $this->current['layout'] . '-container';
		$classes[] = 'clearfix';

		echo join( ' ', $classes );
	}

	/**
	 * Set category in main query
	 *
	 * @param  int $category    Category ID.
	 * @param  int $posts_count Number of posts.
	 */
	public function category_posts( $category, $posts_count ) {
		global $wp_query;

		$wp_query = new WP_Query( 'ignore_sticky_posts=1&category_name=' . $category . '&posts_per_page=' . $posts_count );
	}

	/**
	 * Get section title.
	 *
	 * @param int $category Category id or name.
	 */
	public function get_section_title( $category = false ) {
		if ( blocks_get_settings( 'mts_featured_category_title_' . $this->current['unique_id'] ) ) :
			$category = ! $category ? $this->current['category'] : $category;
		?>
		<div class="title-container title-id-<?php echo $this->current['unique_id']; ?>">
			<?php
			if ( ! $this->current['is_latest'] && 'latest' === $category ) {
				echo '<h3 class="featured-category-title">';
				_e( 'Latest', 'blocks' );
				echo '</h3></div>';
				return;
			}
			$category_name = blocks_get_cat_name( $category );
			$category_id   = get_cat_ID( $category_name );
			?>
			<h3 class="featured-category-title"><a href="<?php echo esc_url( get_category_link( $category_id ) ); ?>" title="<?php echo esc_attr( $category_name ); ?>"><?php echo esc_html( $category_name ); ?></a></h3>
		</div>
		<?php
		endif;
	}

	/**
	 * Get view more button.
	 *
	 * @param int $category Category id or name.
	 */
	public function get_view_more_button() {
		if ( blocks_get_settings( 'post_button_' . $this->current['unique_id'] ) ) {

			$category      = ! $category ? $this->current['category'] : $category;
			$category_name = blocks_get_cat_name( $category );
			$category_id   = get_cat_ID( $category_name );

			printf(
				'<div class="viewMore"><a href="%1$s" title="%2$s">%3$s <i class="fa fa-chevron-right"></i></a></div>',
				esc_url( get_category_link( $category_id ) ),
				esc_attr( $category_name ),
				__( 'View More', 'blocks' )
			);

		}
	}

	/**
	 * Get post title
	 *
	 * @param  boolean $meta     Display meta.
	 * @param  string  $position Position to display meta at.
	 */
	public function get_post_title( $meta = true ) {

		?>
		<header>
			<h2 class="title front-view-title">
				<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php echo the_title(); ?></a>
			</h2>
			<?php
			if ( $meta ) {
				blocks_the_post_meta( 'home', $this->current['unique_id'] );
			}
			?>
		</header>
		<?php
	}

	/**
	 * Get post thumbnail according to layout
	 *
	 * @param  integer $j      Even or Odd.
	 * @param  boolean $avatar Display avatar.
	 */
	public function get_post_thumbnail( $j = 0, $avatar = false ) {
		$default_thumb = 'blocks-featured';
		$thumbs        = array(
			'layout-1' => 'blocks-layout-1',
			'layout-2' => 'blocks-layout-2',
		);
		$size          = isset( $thumbs[ $this->current['posts_layout'] ] ) ? $thumbs[ $this->current['posts_layout'] ] : $default_thumb;
		?>
		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail" class="post-image post-image-left <?php echo $size; ?>">
			<div class="featured-thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $size, array( 'title' => '' ) );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $size . '.png" alt="' . __( 'No Preview', 'blocks' ) . '"  class="wp-post-image" />';
				}
				?>
			</div>
			<?php
			if ( function_exists( 'wp_review_show_total' ) ) {
				wp_review_show_total( true, 'latestPost-review-wrapper' );
			}

			// Author gravatar.
			if ( $avatar && function_exists( 'get_avatar' ) ) {
				echo get_avatar( get_the_author_meta( 'email' ), '57' ); // Gravatar size.
			}
			?>
		</a>
		<?php
	}

	/**
	 * Get post content
	 *
	 * @param  boolean $meta Display meta.
	 */
	public function get_post_content( $meta = true ) {

		if ( $meta ) {
			blocks_the_post_meta( 'home', $this->current['unique_id'] );
		}

		if ( 'layout-2' !== $this->current['layout'] ) {
			?>
			<div class="front-view-content">
				<?php
				if ( empty( blocks_excerpt() ) ) {
					echo blocks_truncate( get_the_content(), $this->current['excerpt_length'], 'words' );
				} else {
					echo blocks_excerpt( $this->current['excerpt_length'] );
				}
				?>
			</div>
			<?php
		}

		if ( blocks_get_settings( 'readmore_' . $this->current['unique_id'] ) ) :
			blocks_readmore();
		endif;
	}

	/**
	 * Get sidebar
	 */
	public function get_sidebar() {
		$cat_name = __( 'Latest ', 'blocks' );
		if ( 'latest' !== $this->current['category'] ) {
			$cat_name = ucwords( blocks_get_cat_name( $this->current['category'] ) );
		}
		if ( 'default' == $this->current['layout'] ) {
			$this->current['layout'] = 'layout-default';
		}
		?>
		<aside id="sidebar" class="sidebar c-4-12 post-<?php echo $this->current['layout']; ?>" role="complementary" itemscope itemtype="http://schema.org/WPSideBar">
			<?php
			dynamic_sidebar( sanitize_title( strtolower( 'post-' . $this->current['layout'] . $cat_name ) ) );
			?>
		</aside>
		<?php
	}

	/**
	 * Get post pagination
	 */
	public function get_post_pagination() {
		if ( ! $this->current['is_latest'] ) {
			blocks_pagination( blocks_get_settings( 'mts_pagenavigation_type' ) );
		}
		wp_reset_query();
	}
}
